# -*- coding: utf-8 -*-

from django.http import HttpResponse, HttpResponseNotModified
from django.utils.http import http_date, parse_http_date_safe

from .timetable import MultipleIterator
import icalendar

from time import time

"""
ICS generator class
Generates an HTTP response with an ICS calendar.
"""


def ics_response(request, timetables, identifier, title):
    # FIXME: Some timetables currently don’t set the last modified timestamp,
    # so we can not know if the ICS was modified since the last time it was
    # fetched by the client.

    # timestamp = max(tt.timestamp for tt in timetables)
    timestamp = time()
    client_timestamp = request.META.get("HTTP_IF_MODIFIED_SINCE")
    if client_timestamp:
        client_timestamp = parse_http_date_safe(parse_http_date_safe)

    if client_timestamp and timestamp > client_timestamp:
        return HttpResponseNotModified()

    cal = icalendar.Calendar()
    cal.add("prodid", "-//net7//{}//FR".format(identifier))
    cal.add("version", "2.0")
    cal.add("x-wr-calname", title)
    cal.add("x-wr-timezone", "Europe/Paris")

    for event, _ in MultipleIterator(timetables):
        ics_event = icalendar.Event()

        if event.type:
            summary = str(event.type) + " - " + str(event.title)
        else:
            summary = event.title

        ics_event.add("summary", summary)
        ics_event.add("dtstart", event.start)
        ics_event.add("dtend", event.end)
        ics_event.add("uid", event.uid)
        ics_event.add("location", ", ".join(event.locations))
        if event.people:
            ics_event.add("description", "Avec " + ", ".join(event.people))

        cal.add_component(ics_event)

    response = HttpResponse(content_type="text/calendar; charset=UTF-8")
    response["Last-Modified"] = http_date(timestamp)
    response["Expires"] = http_date(time() + 10)
    response.write(cal.to_ical())

    return response
